Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(895)

Unified Diff: chrome/browser/performance_monitor/performance_monitor_util.h

Issue 10860017: Refactor Metrics (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Nitfix + latest master for cq Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/performance_monitor/performance_monitor_util.h
diff --git a/chrome/browser/performance_monitor/performance_monitor_util.h b/chrome/browser/performance_monitor/performance_monitor_util.h
index 9d2eca288b54a427b4d553cc2678abb89d227c96..475dfafd1b20e102d63566249e0f7ada811684e6 100644
--- a/chrome/browser/performance_monitor/performance_monitor_util.h
+++ b/chrome/browser/performance_monitor/performance_monitor_util.h
@@ -8,23 +8,23 @@
#include "base/callback.h"
#include "base/time.h"
#include "base/tracked_objects.h"
+#include "chrome/browser/performance_monitor/database.h"
#include "chrome/browser/performance_monitor/event.h"
-#include "chrome/browser/performance_monitor/metric_info.h"
+#include "chrome/browser/performance_monitor/metric.h"
#include "chrome/common/extensions/extension_constants.h"
namespace performance_monitor {
namespace util {
// Metric data can be either dense or sporadic, so AggregateMetric() normalizes
// the metric data in time. |metric_infos| must be sorted in increasing time.
// Put concisely, AggregateMetric() does sample rate conversion from irregular
// metric data points to a sample period of |resolution| beginning at |start|.
// Each sampling window starts and ends at an integer multiple away from
// |start| and data points are omitted if there are no points to resample.
-std::vector<MetricInfo> AggregateMetric(
- const std::vector<MetricInfo>& metric_infos,
- const base::Time& start,
- const base::TimeDelta& resolution);
+Database::MetricVector AggregateMetric(const Database::MetricVector& metrics,
+ const base::Time& start,
+ const base::TimeDelta& resolution);
// Posts |request| to the performance monitor database's sequenced thread. On
// completion |reply| is posted to the thread that called
@@ -8,23 +8,23 @@
namespace util {
// Metric data can be either dense or sporadic, so AggregateMetric() normalizes
-// the metric data in time. |metric_infos| must be sorted in increasing time.
+// the metric data in time. |metrics| must be sorted in increasing time.
// Put concisely, AggregateMetric() does sample rate conversion from irregular
// metric data points to a sample period of |resolution| beginning at |start|.

Powered by Google App Engine
This is Rietveld 408576698